@@ -33,6 +33,7 @@ class FakeArgs(object):
 
         self.files: List[str] = []
         self.languages: List[str] = []
+        self.languages_skip: List[str] = []
         self.separator: Union[str, None] = None
         self.comment_marker: Union[str, None] = None
 
@@ -44,6 +45,9 @@ class FakeArgs(object):
             self.__setattr__(option_name, False)
             self.__setattr__(f'no_{option_name}', False)
 
+        self.checkers = []
+        self.checks = {}
+
 
 class TestConfigBuilder(TestCase):
 
@@ -53,12 +57,10 @@ class TestConfigBuilder(TestCase):
         """
         fake_args = FakeArgs()
         config = Config()
-        for key, val in config.__dict__.items():
+        for key in config.__dict__:
             # Let's skip Checks' info.
-            if isinstance(val, dict):
-                continue
-
-            self.assertIn(key, fake_args.__dict__, f'FakeArgs lacks "{key}" key."')
+            if key not in {'checks'}:  # noqa: WPS525
+                self.assertIn(key, fake_args.__dict__, f'FakeArgs lacks "{key}" key."')
 
     def test_fake_args_matches_argparse(self) -> None:
         """
@@ -70,7 +72,8 @@ class TestConfigBuilder(TestCase):
         sys.argv[1:] = []  # noqa: WPS362
         args = ConfigBuilder._parse_args()
         for key in fake_args.__dict__:
-            self.assertIn(key, args)
+            if key not in {'checks'}:  # noqa: WPS525
+                self.assertIn(key, args)
 
     # #################################################################################################
 
@@ -252,6 +255,42 @@ class TestConfigBuilder(TestCase):
         self.assertEqual(args.separator, config.separator)
         self.assertEqual(args.comment_marker, config.comment_marker)
 
+    def test_set_from_args_with_spaces(self) -> None:
+        """
+        Ensures languages specified as space separated string are processed as expected.
+        """
+        # FIXME: make list more random
+        lang = ['de', 'fr', 'en']
+        lang_str = ' '.join(lang)
+        args = self._generate_fake_args([lang_str])
+
+        # This is going to be our reference default config instance.
+        config_defaults = Config()
+
+        # Process args and update config
+        config = Config()
+        ConfigBuilder._set_from_args(config, args)
+
+        # Ensure config reflects changes from command line
+        exp_fatal = self._get_expectation(config_defaults.fatal, args.fatal, args.no_fatal)
+        self.assertEqual(exp_fatal, config.fatal)
+        exp_color = self._get_expectation(config_defaults.color, args.color, args.no_color)
+        self.assertEqual(exp_color, config.color)
+
+        self.assertEqual(args.update, config.update)
+        self.assertEqual(args.create, config.create)
+
+        # log_level controlled by `quiet` and `verbose`.
+        self.assertEqual(args.quiet, config.quiet)
+        self.assertEqual(args.verbose, config.verbose)
+
+        # Ensure all files are there and still with proper suffix.
+        for idx, args_file in enumerate(args.files):
+            self.assertEqual(config.files[idx], args_file)
+        self.assertEqual(lang, config.languages)
+        self.assertEqual(args.separator, config.separator)
+        self.assertEqual(args.comment_marker, config.comment_marker)
+
     # #################################################################################################
 
     def test_add_file_suffix_missing_suffix(self) -> None:
@@ -265,7 +304,7 @@ class TestConfigBuilder(TestCase):
         dests = copy.copy(srcs)
         # WHEN we process it
         ConfigBuilder._add_file_suffix(config, dests)
-        # THEN all file names should have file suffix appened.
+        # THEN all file names should have file suffix appended.
         for idx, src in enumerate(srcs):
             self.assertEqual(f'{str(src)}{config.file_suffix}', str(dests[idx]))
 
@@ -378,6 +417,18 @@ class TestConfigBuilder(TestCase):
 
     # #################################################################################################
 
+    def test_get_checkers_from_args(self) -> None:
+        config = Config()
+
+        # Pass no args for parsing (this is legit as we have config file that can provide what's needed).
+        sys.argv[1:] = []  # noqa: WPS362
+        args = ConfigBuilder._parse_args()
+        for key in config.__dict__:
+            if key not in {'checks'}:  # noqa: WPS525
+                self.assertIn(key, args)
+
+    # #################################################################################################
+
     def test_parse_args_returns_all_keys(self) -> None:
         """
         Checks if argparse returned dict contains all the keys we expect to be present while building
@@ -389,7 +440,8 @@ class TestConfigBuilder(TestCase):
         sys.argv[1:] = []  # noqa: WPS362
         args = ConfigBuilder._parse_args()
         for key in config.__dict__:
-            self.assertIn(key, args)
+            if key not in {'checks'}:  # noqa: WPS525
+                self.assertIn(key, args)
 
     def test_parse_args_returns_no_more_keys(self) -> None:
         """
@@ -410,6 +462,7 @@ class TestConfigBuilder(TestCase):
         # FIXME: this should not be hardcoded here!
         del args['show_version']
         del args['config_dump']
+        del args['checkers']
 
         for key in args:
             # Ensure key args returns is what is present in Config as well.
@@ -423,7 +476,7 @@ class TestConfigBuilder(TestCase):
         args = self._generate_fake_args(languages)
 
         config = Config()
-        file = self.get_random_string('file_')
+        file = self.get_random_string('file')
         config.files.append(file)
 
         # Pass no args for parsing (this is legit as we have config file that can provide what's needed).
@@ -433,7 +486,7 @@ class TestConfigBuilder(TestCase):
 
             ConfigBuilder.build(config)
 
-            # TODO: make comparision more detailed; add test for langs as well
+            # TODO: make comparison more detailed; add test for langs as well
             self.assertEqual(len(config.files), len(config.files))
             for idx, def_file in enumerate(config.files):
                 self.assertEqual(def_file, config.files[idx])
